#!/bin/sh
# ----------------------------------------------------------------------------
# /tmp/preinstall.sh - autohalt preinstallation script
#
# Creation   : 2009-01-03 christian
# Last update: $Id: preinstall.sh 10 2009-01-03 11:52:27Z christian $
#
# Copyright (c) 2009 Christian Richter, <richterch(at)gmx(dot)de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# set packages name
packageName=autohalt
filelist=/etc/filelist.d/autohalt-files.txt

# ----------------------------------------------------------------------------
# Check for old installation
# ----------------------------------------------------------------------------
checkVersion=`/var/install/bin/check-version autohalt 0.1.16`

# ----------------------------------------------------------------------------
# Update system
# ----------------------------------------------------------------------------
case "${checkVersion}" in
    old)
        if [ -f /var/install/deinstall/autohalt ]
        then
            sh /var/install/deinstall/autohalt update
        fi
    ;;
    new|installed)
        echo "Updating package 'autohalt' (removing previous version)"
        filesToLeave="etc/config.d/autohalt
                      etc/backup.d/autohalt*
                      etc/filelist.d/autohalt-files.txt
                      var/install/deinstall/autohalt
                      var/install/menu/setup.services.autohalt*"
        /etc/init.d/autohalt stop
        # --------------------------------------------------------------------
        # Remove package content except some special files if it's an update
        # instead of a deinstallation
        # --------------------------------------------------------------------
        while read id perm user group package file
        do
            # ------------------------------------------------
            # Remove file only if it is not on the ignore list
            removeCurrentFile=true
            for currentFileToLeave in "${filesToLeave}"
            do
            if [ "${currentFileToLeave}" == "${file}" ]
            then
                removeCurrentFile=false
                break
            fi
            done

            if ${removeCurrentFile}
            then
                case ${id} in
                    b|u)
                        if [ "${file}" != "tmp/install.sh" -a "${file}" != "tmp/preinstall.sh" ]
                        then
                            rm -f /${file}
                        fi
                    ;;

                    f)
                        # Remove directories
                        rmdir --ignore-fail-on-non-empty /${file}
                    ;;
                esac
            fi
        done < ${filelist}  
        # ----------------------------------------------------------------------------
        # Check files and default config must be removed separately because they
        # are not on the file list if the package is used as it was created by
        # create-package-new.sh, they are created dynamically during installation.
        # ----------------------------------------------------------------------------
        rm -f /etc/check.d/autohalt*
        rm -f /etc/default.d/autohalt*
        rm -f /etc/logrotate.d/autohalt
        rm -f /var/log/autohalt*
        rm -f /etc/rc?.d/???$packageName 
    ;;
    *)
        exit 0
    ;;  
esac


exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
