#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/autohalt-update.sh - paramater update script
#
# Creation   : 2009-01-03 christian
# Last update: $Id: autohalt-update.sh 17 2009-01-15 13:13:05Z christian $
#
# Copyright (c) 2009 the Christian Richter, <richterch(at)gmx(dot)de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/autohalt-update-trace$$.log
#set -x

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=autohalt

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------

# Basic Configuration
START_AUTOHALT='no'
AUTOHALT_DO_DEBUG='no'

# Lock Processes
AUTOHALT_CHECK_PROCESS='no'
AUTOHALT_LOCK_PROCESS_N='1'
AUTOHALT_LOCK_PROCESS_1='foo.bar'

# Check Users
AUTOHALT_CHECK_USERS='no'
AUTOHALT_CHECK_ALL_USERS='no'
AUTOHALT_MAX_LOGIN_DAYS='1'
AUTOHALT_CHECK_SINGLE_USER_N='1'
AUTOHALT_CHECK_SINGLE_USER_1='root'

# Check IP
AUTOHALT_CHECK_IP='no'
AUTOHALT_IP_RANGE_N='1'
AUTOHALT_IP_RANGE_1='192.168.0.1 192.168.0.10'
AUTOHALT_IP_N='1'
AUTOHALT_IP_1='192.168.1.1'

# Additional Configuration
AUTOHALT_EXEC='no'
AUTOHALT_EXEC_N='1'
AUTOHALT_EXEC_1='dosomething.sh'
AUTOHALT_NO_RESPONSE=''
AUTOHALT_TRIALS='1'
AUTOHALT_SCHEDULE_START_HOUR='1'
AUTOHALT_SCHEDULE_END_HOUR='7'
AUTOHALT_CRON_INTERVAL='15'

# Logging Configuration
AUTOHALT_LOG='yes'
AUTOHALT_LOG_COUNT='3'
AUTOHALT_LOG_INTERVAL='weekly'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/autohalt ]
    then
        . /etc/config.d/autohalt
        if [ "${AUTOHALT_START}" ]
        then
            START_AUTOHALT="${AUTOHALT_START}"
        fi
        if [ "${AUTOHALT_CHECK_USER}" ]
        then
            AUTOHALT_CHECK_ALL_USERS="${AUTOHALT_CHECK_USER}"
        fi
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf autohalt "2009-01-03" "christian"
    # ------------------------------------------------------------------------


    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_AUTOHALT"    "Use: yes or no"
    printvar "AUTOHALT_DO_DEBUG" "Use: yes or no. yes will prevent the server"
    printvar ""                  "from going down."

    # ------------------------------------------------------------------------
    printgroup "Lock Processes"
    # ------------------------------------------------------------------------
    printvar "AUTOHALT_CHECK_PROCESS"  "Use: yes or no"
    echo
    printvar "AUTOHALT_LOCK_PROCESS_N" "Number of lock processes "
    # begin process
    idx=1
    while [ "${idx}" -le "${AUTOHALT_LOCK_PROCESS_N}" ]
    do
        printvar "AUTOHALT_LOCK_PROCESS_${idx}" "if specified process running"
        printvar ""                             "the server will not shutdown"
        idx=`/usr/bin/expr ${idx} + 1`
    done

    # ------------------------------------------------------------------------
    printgroup "Check Users"
    # ------------------------------------------------------------------------
    printvar "AUTOHALT_CHECK_USERS"         "Use: yes or no"
    echo
    printvar "AUTOHALT_CHECK_ALL_USERS"     "use /etc/passwd for check"
    echo
    printvar "AUTOHALT_CHECK_SINGLE_USER_N" "How many users do you want"
    printvar ""                             "to ckeck for"
    # beginn single user
    idx=1
    while [ "${idx}" -le "${AUTOHALT_CHECK_SINGLE_USER_N}" ]
    do
        printvar "AUTOHALT_CHECK_SINGLE_USER_${idx}" "Default: root"
        idx=`/usr/bin/expr ${idx} + 1`
    done
    echo
    printvar "AUTOHALT_MAX_LOGIN_DAYS"      "last login was xx days ago"

    # ------------------------------------------------------------------------
    printgroup "Check IP"
    # ------------------------------------------------------------------------
    printvar "AUTOHALT_CHECK_IP"        "Use: yes or no"
    echo
    printvar "AUTOHALT_IP_RANGE_N"      "Number of IP-ranges"
    # begin range
    idx=1
    while [ "${idx}" -le "${AUTOHALT_IP_RANGE_N}" ]
    do
        printvar "AUTOHALT_IP_RANGE_${idx}" "range of IP adresses whitch were pinged"
        idx=`/usr/bin/expr ${idx} + 1`
    done
    echo
    printvar "AUTOHALT_IP_N"            "Number of unique IP's"
    # begin unique
    idx=1
    while [ "${idx}" -le "${AUTOHALT_IP_N}" ]
    do
        printvar "AUTOHALT_IP_${idx}"        "IP Number or internet-name"
        printvar ""                         "e.g. (www.foo.bar)"
        idx=`/usr/bin/expr ${idx} + 1`
    done

    # ------------------------------------------------------------------------
    printgroup "Additional Configuration"
    # ------------------------------------------------------------------------
    printvar "AUTOHALT_EXEC"                "Use: yes or no"
    printvar "AUTOHALT_EXEC_N"              "number of commands"
    idx=1
    while [ "${idx}" -le "${AUTOHALT_EXEC_N}" ]
    do
        printvar "AUTOHALT_EXEC_${idx}" "run command/script before shutdown"
        idx=`/usr/bin/expr ${idx} + 1`
    done

    printvar "AUTOHALT_NO_RESPONSE"         "timeout for clients in seconds"
    printvar "AUTOHALT_TRIALS"              "how many times should Autohalt check the clients"
    printvar "AUTOHALT_SCHEDULE_START_HOUR" "start time e.g. 1 o'clock "
    printvar "AUTOHALT_SCHEDULE_END_HOUR"   "end time  e.g. 7 o'clock"
    printvar "AUTOHALT_CRON_INTERVAL"       "interval in minutes e.g. every 15 minutes"

    # ------------------------------------------------------------------------
    printgroup "Logging Configuration"
    # ------------------------------------------------------------------------
    printvar "AUTOHALT_LOG"          "log autohalt"
    printvar "AUTOHALT_LOG_COUNT"    "number of log files to save"
    printvar "AUTOHALT_LOG_INTERVAL" "interval: daily, weekly, monthly"

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{
    printgpl -check autohalt '2009-01-03' 'christian' >/etc/check.d/autohalt
    cat >> /etc/check.d/autohalt <<EOFG
# Variable                    OPT_VARIABLE            VARIABLE_N                    VALUE
START_AUTOHALT                -                       -                             YESNO
AUTOHALT_DO_DEBUG             START_AUTOHALT          -                             YESNO
AUTOHALT_CHECK_PROCESS        START_AUTOHALT          -                             YESNO
AUTOHALT_LOCK_PROCESS_N       AUTOHALT_CHECK_PROCESS  -                             NUMERIC
AUTOHALT_LOCK_PROCESS_%       AUTOHALT_CHECK_PROCESS  AUTOHALT_LOCK_PROCESS_N       NOTEMPTY
AUTOHALT_CHECK_USERS          START_AUTOHALT          -                             YESNO
AUTOHALT_CHECK_ALL_USERS      AUTOHALT_CHECK_USERS    -                             YESNO
AUTOHALT_CHECK_SINGLE_USER_N  AUTOHALT_CHECK_USERS    -                             NUMERIC
AUTOHALT_CHECK_SINGLE_USER_%  AUTOHALT_CHECK_USERS    AUTOHALT_CHECK_SINGLE_USER_N  AUTOHALT_CHOOSE_USER_CUI
AUTOHALT_MAX_LOGIN_DAYS       AUTOHALT_CHECK_USERS    -                             TRIALS
AUTOHALT_CHECK_IP             START_AUTOHALT          -                             YESNO
AUTOHALT_IP_RANGE_N           AUTOHALT_CHECK_IP       -                             NUMERIC
AUTOHALT_IP_RANGE_%           AUTOHALT_CHECK_IP       AUTOHALT_IP_RANGE_N           RANGE
AUTOHALT_IP_N                 AUTOHALT_CHECK_IP       -                             NUMERIC
AUTOHALT_IP_%                 AUTOHALT_CHECK_IP       AUTOHALT_IP_N                 HOST
AUTOHALT_EXEC                 START_AUTOHALT          -                             YESNO
AUTOHALT_EXEC_N               AUTOHALT_EXEC           -                             NUMERIC
AUTOHALT_EXEC_%               AUTOHALT_EXEC           AUTOHALT_EXEC_N               NONE
AUTOHALT_NO_RESPONSE          START_AUTOHALT          -                             ENUMERIC
AUTOHALT_TRIALS               START_AUTOHALT          -                             TRIALS
AUTOHALT_SCHEDULE_START_HOUR  START_AUTOHALT          -                             NUMERIC
AUTOHALT_SCHEDULE_END_HOUR    START_AUTOHALT          -                             NUMERIC
AUTOHALT_CRON_INTERVAL        START_AUTOHALT          -                             NUMERIC
AUTOHALT_LOG                  START_AUTOHALT          -                             YESNO
AUTOHALT_LOG_COUNT            AUTOHALT_LOG            -                             NUMERIC
AUTOHALT_LOG_INTERVAL         AUTOHALT_LOG            -                             AUTOHALT_CHOOSE_LOG_INTERVAL_CUI
EOFG

    # Set rights for check.d file
    chmod 0600 /etc/check.d/autohalt
    chown root /etc/check.d/autohalt


    printgpl -check_exp autohalt '2009-01-03' 'christian' >/etc/check.d/autohalt.exp
    cat >> /etc/check.d/autohalt.exp <<EOFG
RANGE                             =  '(RE:IPADDR)[[:space:]]+(RE:IPADDR)'
                                  :  'no valid range'
HOST                              =  '(RE:IPADDR)|(RE:FQDN)'
                                  :  'only IP-adress or internet name allowed'
TRIALS                            =  '[1-9]+'
                                  :  'must be 1 or higher'
AUTOHALT_CHOOSE_LOG_INTERVAL_CUI  =  'daily|weekly|monthly'
                                  :  'no valid interval, should be daily, weekly or monthly'
AUTOHALT_CHOOSE_USER_CUI          =  '(RE:NOTEMPTY)'
                                  :  'You must choose a valid user'

EOFG

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/autohalt.exp
    chown root /etc/check.d/autohalt.exp


#    printgpl -check_ext autohalt '2009-01-03' 'christian' >/etc/check.d/autohalt.ext
#    cat >> /etc/check.d/autohalt.ext <<EOFG
#
#
#EOFG
#
#    # Set rights for check.ext file
#    chmod 0600 /etc/check.d/autohalt.ext
#    chown root /etc/check.d/autohalt.ext
}



# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file
if [ -f /etc/config.d/autohalt ]
then
    mecho -info -n "Updating configuration. "
else
    mecho -info -n "creating configuration. "
fi

makeConfigFile /etc/default.d/autohalt

# Update from old version
mecho -info -n "."
renameOldVariables

# Write new config file
mecho -info -n "."
makeConfigFile /etc/config.d/autohalt

# Write check.d file
mecho -info -n "."
makeCheckFile

mecho -info "Finished."

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------